Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EnableLogging ¶
func ListParams ¶
Types ¶
type API ¶
type API struct {
Name string
BaseURL string
Header map[string]StringOrList //[]string
Query map[string]StringOrList //[]string
Commands []Command
Set *APISet
}
API in a set for multiple Commands
type APISet ¶
type APISet struct {
APIs []API `json:"apis"`
}
APISet for multiple APIs
func (*APISet) CreateRequest ¶
CreateRequest by searching the set for a single api/command combination
type Command ¶
type Command struct {
Name string
Path string
Method string
Header map[string]StringOrList //[]string
Query map[string]StringOrList //[]string
Body *CommandBody
API *API
}
Command on an API
type CommandBody ¶
type CommandBody struct {
Data []byte
}
func (*CommandBody) String ¶
func (body *CommandBody) String() string
func (*CommandBody) UnmarshalJSON ¶
func (body *CommandBody) UnmarshalJSON(data []byte) error
type InvalidOperation ¶
type InvalidOperation string
InvalidOperation error
func (InvalidOperation) Error ¶
func (e InvalidOperation) Error() string
type SourceErrorFn ¶
type SourceErrorFn func(error)
type SourceFn ¶
func NewEnvVarsSource ¶
NewEnvVarsSource allows environment variables to be a data source
func NewFlagSource ¶
func NewFlagSource(args []string, errLog SourceErrorFn) SourceFn
type StringOrList ¶
type StringOrList []string
func (StringOrList) MarshalJSON ¶
func (s StringOrList) MarshalJSON() ([]byte, error)
func (*StringOrList) UnmarshalJSON ¶
func (s *StringOrList) UnmarshalJSON(data []byte) error
Click to show internal directories.
Click to hide internal directories.